function runRecalibrateFromFile()
    %Load a .mat calibration file. Redo the calibration using the original
    %pressures. Do a 2C calibration as well, and compare the 4C and 2C
    %calibraitons.

    addpath('../m');
    addpath('./m');
    addpath('./jba');
    addpath('./mat');

    %NOTE on notation: Kappa is the complex propagation factor

    %MTK: If you want a hardcoded file, put it here and comment out the call to getRecalibrationFile()
    % file = 'lastCalibration.mat';
    file = getRecalibrationFile();

    if file == 0
        disp('no file selected... exiting')
        return;
    end

    %This loads the file and does the 4C Calibration
    [Zs, Ps, lengths, Hcavities, cal, sig, Kappa_theoretical] = recalibrateFromFile(file);

    %Run JBA Analysis, including plots (only do speaker channel 1)
    %This also prints eps files, so it takes a few seconds to run
    FourCCompute(Hcavities{1}, Ps(1, :), Zs(1, :), cal, sig, lengths(1, :)', Kappa_theoretical)

    %1: Reflectance and Pressure formulation (default)
    %2: Impedance and Pressure
    %3: Admittance and Pressure
    %4: Admittance and 1/Pressure
    equation_formualtion = 1;

    %Replace this if you have a different way of computing Kappa
    [~, Kappa_theoretical] = keefe(cal.cavityDiameter, sig.FrequenciesAll);

    %4 X 1025 de-chirped pressures. First dimension is cavity number,
    %second dimension is frequency index
    Pressures = Hcavities{1};

    %Choose any number of cavity pairs to 2ccalibrate and plot
    cavity_pairs = [3, 4; ...
                    1, 2; ...
                    2, 4];

    %2C Calibrate each cavity pair and plot the Reflectance error
    for iPair = 1:size(cavity_pairs, 1)

        %Do the 2C calibration on channel 1
        [Ps_2c, Zs_2c] = calcTheveninParameters(lengths(1, cavity_pairs(iPair, :))', Hcavities{1}(cavity_pairs(iPair, :), :), Kappa_theoretical, equation_formualtion);

        %MTK plotting function
        compare2Cand4C(Hcavities, sig, Zs, Ps, Zs_2c, Ps_2c, Kappa_theoretical, lengths(1, :));

    end

    rmpath('../m');
    rmpath('jba');

end

function fullpath = getRecalibrationFile()
    %Let the user pick a mat file
    %Use a default based on previously used file
    %Save the new file as default

    if exist('lastRecalibrationFile.txt', 'file')

        fid = fopen('lastRecalibrationFile.txt', 'r');
        file0 = fgetl(fid);
        fclose(fid);

    else

        file0 = '';
    end

    [file, path] = uigetfile('*.mat', 'Select a calibration file...', file0);

    fullpath = strcat(path, file);

    if file ~= 0

        fid = fopen('lastRecalibrationFile.txt', 'w');
        fprintf(fid, fullpath);
        fclose(fid);
    end

end
