
%--------------------------------------------------------------------------
function z0=z0_earcanal
% ear-canal charact imp
dia=7.5000; % mm, tip 14A
% rhoc is based on Keefe's equations (keefe.m). 
% factor 10 is to go from g/(cm^2.s) to kg/(m^2.s)=MKS
% temperature T=18 deg Celsius
const_rhoc=41.4687; % %g/(cm^2.s)
rho0c = 10*const_rhoc; 
A = pi/4*(dia *1e-3)^2;
z0 = rho0c/A; % This z0 is the surge resistance (jba says on 2013-03-24).
return

%--------------------------------------------------------------------------
function [Zc,Gamma,Z0] = keefe(dia,f,temp)
% Calculate cavity model parameters.
% Usage: [Zc,Gamma,Z0] = keefe(dia,f,temp);
% Keefe, JASA, Vol.75 No.1, Jan. 1984 (Pg. 58-62)
% a JBA creation...modified 5/2/00 by Tony Miller
% all cgs units
% vectorized with respect to length len of size(1,number_of_cavities), pb may-2001
% input lenght 'len' in mm
% impedance is normalized to tube characteristic impedance without loss

   w = 2*pi*f;			         % radians
   radius = dia/20; 	       % mm to cm
   dt = (temp-27);       % degrees C

   area = pi*(radius)^2;     		    % cm^2

   rho = (1-0.00335*dt)*1.1769e-3; % g/cm^3
   eta = (1+0.0025*dt)*1.846e-4; % g/(s*cm)
   c = (1+0.00166*dt)*3.4723e4; % cm/s
   Z0 = ((rho*c)/area); 

   rv = radius*sqrt(rho*w/eta); 	  % dimensionless
   ro = rho*c/area;             % surge resistance, jba's 

   Zor = ro*(1+0.369./rv);					% real(characteristic impedance)
   Zoi = -ro*(0.369./(rv) + 1.149./(rv.^2) +0.303./(rv.^3)); % imag(characteristic impedance)

   alpha = (w/c).*(1.045./(rv) + 1.08./(rv.^2) + 0.75./(rv.^3)); % real(propagation const)
   beta = (w/c).*(1+1.045./rv); % imag(propagation const)

   Zo = Zor + (i*Zoi);   % characteristic impedance of tube (with loss)
   gamma = alpha + (i*beta); % in 1/cm

   n=1;
   nf=length(gamma);

   Zc = Zo(ones(n,1),1:nf); % normalized characteristic impedance of tube (with loss)

   Gamma=gamma/10; % in 1/mm
   
   % change Z0 and Zc to mks units
   Z0 = Z0 * 1e5;
   Zc = Zc * 1e5;
   
return



